.. _sec-citation:

==============
Citing msprime
==============


If you use ``msprime`` in your work, please cite the
`PLoS Computational Biology paper <http://dx.doi.org/10.1371/journal.pcbi.1004842>`_:

Jerome Kelleher, Alison M Etheridge and Gilean McVean (2016), *Efficient Coalescent
Simulation and Genealogical Analysis for Large Sample Sizes*, PLoS Comput Biol
12(5): e1004842. doi: 10.1371/journal.pcbi.1004842

Bibtex record::

    @article{10.1371/journal.pcbi.1004842,
    author = {Kelleher, Jerome AND Etheridge, Alison M AND McVean, Gilean},
    journal = {PLoS Comput Biol},
    title = {Efficient Coalescent Simulation and Genealogical Analysis for Large Sample Sizes},
    year = {2016},
    month = {05},
    volume = {12},
    url = {http://dx.doi.org/10.1371%2Fjournal.pcbi.1004842},
    pages = {1-22},
    number = {5},
    doi = {10.1371/journal.pcbi.1004842}
    }
